@@ -18,7 +18,7 @@ from openid.message import NamespaceMap
 
 from .store import DjangoOpenIDStore
 from .forms import ChangePasswordForm
-from .constants import AX_MAPPINGS, AX_OLDPASSWD, AX_NEWPASSWD
+from .constants import AX_MAPPINGS, AX_OLDPASSWD, AX_NEWPASSWD, AX_IS_VERIFIED
 
 AXData = collections.namedtuple('AXData', ['ax_alias', 'field_name', 'value'])
 
@@ -82,6 +82,18 @@ def build_return_to_url(request, return_view, redirect_field_name,
     return return_to
 
 
+def _prepare_ax_fetch_request():
+    if not any([
+            getattr(settings, 'AX_FETCH_IS_VERIFIED', False)]):
+        return None
+
+    ax_request = ax.FetchRequest()
+    if getattr(settings, 'AX_FETCH_IS_VERIFIED', False):
+        ax_request.add(ax.AttrInfo(AX_MAPPINGS[AX_IS_VERIFIED][0], required=True, alias='verified'))
+
+    return ax_request
+
+
 def login_begin(request, redirect_field_name=REDIRECT_FIELD_NAME,
                 template_name='openid/response.html', immediate=False):
 
@@ -107,9 +119,12 @@ def login_begin(request, redirect_field_name=REDIRECT_FIELD_NAME,
             {'message': "OpenID discovery error: %s" % str(exc)}
         )
 
-    openid_request.addExtension(
-        sreg.SRegRequest(optional=get_sreg_settings())
-    )
+    sreg_request = sreg.SRegRequest(optional=get_sreg_settings())
+    openid_request.addExtension(sreg_request)
+
+    ax_request = _prepare_ax_fetch_request()
+    if ax_request:
+        openid_request.addExtension(ax_request)
 
     return_to = build_return_to_url(request, login_complete,
                                     redirect_field_name, redirect_to)
@@ -127,9 +142,9 @@ def login_complete(request, redirect_field_name=REDIRECT_FIELD_NAME,
             return render(
                 request, template_name, {'message': 'Unkown user'}
             )
-        if getattr(user, 'requires_validated_email', False):
+        if getattr(user, 'requires_verified_email', False):
             return render(
-                request, template_name, {'message': 'Validate your email'}
+                request, template_name, {'message': 'Verify your email'}
             )
         if not user.is_active:
             return render(
